==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Dimension/ts/Dimension_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>Dimension</name>
    <message>
        <location filename="../Dimension.js" line="+63"/>
        <source>No prefix</source>
        <translatorcomment>--google--
&lt;brak przedrostka&gt;</translatorcomment>
        <translation type="unfinished">Bez prefiksu</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Radius</source>
        <translatorcomment>--exact match--
--file: designer_pl.ts--
Wskaż promień
Łuk styczny do głównego obiektu z promieniem</translatorcomment>
        <translation type="unfinished">Promień</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Metric screw</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Wkręt metryczny</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Diameter</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Przełącz znak średnicy
ø (Średnica)</translatorcomment>
        <translation type="unfinished">Średnica</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plus/Minus</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Plus / Minus</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Almost equal to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Asymptotically equal to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Square</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Kwadrat</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Delta</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Delta</translation>
    </message>
    <message>
        <location line="+58"/>
        <source>Dimension Tools</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Narzędzia wymiarowe</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show dimension tools</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Pokaż narzędzia rozmiarom</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>D&amp;imension</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Wymiar</translation>
    </message>
    <message>
        <location filename="../Dimension.ui" line="+29"/>
        <source>Label:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Etykieta:
Etykieta wymiarowania:</translatorcomment>
        <translation type="unfinished">Etykieta:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Prefix</source>
        <translatorcomment>--google--
Przedrostek globalny:
Przedrostek globalny
Wywiedź przedrostek z nazw plików</translatorcomment>
        <translation type="unfinished">Prefiks</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Enter fixed label or leave empty for automatic label</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wprowadź stałą etykietę lub pozostaw puste aby otrzymać etykietę automatyczną</translatorcomment>
        <translation type="unfinished">Wprowadź stałą etykietę lub pozostaw puste aby otrzymać etykietę automatyczną</translation>
    </message>
    <message>
        <location line="+61"/>
        <source>Upper tolerance</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Górna tolerancja</translatorcomment>
        <translation type="unfinished">Górna tolerancja</translation>
    </message>
    <message>
        <location line="+54"/>
        <source>Lower tolerance</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Dolna tolerancja</translatorcomment>
        <translation type="unfinished">Dolna tolerancja</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Scale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Drawing Scale</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Dimension/ts/Dimension_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Dimension</name>
    <message>
        <location filename="../Dimension.js" line="+63"/>
        <source>No prefix</source>
        <translatorcomment>--google--
&lt;brak przedrostka&gt;</translatorcomment>
        <translation>Bez prefiksu</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Radius</source>
        <translatorcomment>--exact match--
--file: designer_pl.ts--
Wskaż promień
Łuk styczny do głównego obiektu z promieniem</translatorcomment>
        <translation>Promień</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Metric screw</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Gwint metryczny</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Diameter</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Przełącz znak średnicy
ø (Średnica)</translatorcomment>
        <translation>Średnica</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arc</source>
        <translation>Łuk</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plus/Minus</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Plus/Minus</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Almost equal to</source>
        <translation>Prawie równe</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Asymptotically equal to</source>
        <translation>Asymptotycznie równe</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Square</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Kwadrat</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Delta</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Delta</translation>
    </message>
    <message>
        <location line="+79"/>
        <source>Dimension Tools</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Narzędzia wymiarów</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show dimension tools</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Wyświetla narzędzia wymiarów</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>D&amp;imension</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>&amp;Wymiar</translation>
    </message>
    <message>
        <location filename="../Dimension.ui" line="+29"/>
        <source>Label:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Etykieta:
Etykieta wymiarowania:</translatorcomment>
        <translation>Etykieta:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Prefix</source>
        <translatorcomment>--google--
Przedrostek globalny:
Przedrostek globalny
Wywiedź przedrostek z nazw plików</translatorcomment>
        <translation>Prefiks</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Enter fixed label or leave empty for automatic label</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wprowadź stałą etykietę lub pozostaw puste aby otrzymać etykietę automatyczną</translatorcomment>
        <translation>Wprowadza określoną etykietę lub nadaje etykietę automatyczną dla pustego pola</translation>
    </message>
    <message>
        <location line="+61"/>
        <source>Upper tolerance</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Górna tolerancja</translatorcomment>
        <translation>Górna odchyłka</translation>
    </message>
    <message>
        <location line="+54"/>
        <source>Lower tolerance</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Dolna tolerancja</translatorcomment>
        <translation>Dolna odchyłka</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Scale</source>
        <translation>Podziałka</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Drawing Scale</source>
        <translation>Podziałka rysunku</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Auto</source>
        <translation>Automatycznie</translation>
    </message>
</context>
</TS>
